From 0fd1f748fd18f87efdafabfa21e1e4385ea71050 Mon Sep 17 00:00:00 2001
From: Uwe Risse <dg2ycb@gmx.de>
Date: Sat, 7 Jan 2023 09:57:14 +0100
Subject: [PATCH 1/4] Better initialization of the decoded text font.

---
 widgets/mainwindow.cpp | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

From 4ed849580ccaba9a70c52734cc361e344916d12a Mon Sep 17 00:00:00 2001
From: Uwe Risse <dg2ycb@gmx.de>
Date: Sat, 7 Jan 2023 10:19:38 +0100
Subject: [PATCH 2/4] Preparations for the v2.6.1 release.

---
 CMakeLists.txt    |  2 +-
 NEWS              | 18 +++++++++++++++++-
 Release_Notes.txt | 16 ++++++++++++++++
 3 files changed, 34 insertions(+), 2 deletions(-)

diff --git a/CMakeLists.txt b/CMakeLists.txt
index e16965830..86bc970c6 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -45,7 +45,7 @@ if (POLICY CMP0075)
 endif ()
 
 project (wsjtx
-  VERSION 2.6.0.0
+  VERSION 2.6.1.0
   LANGUAGES C CXX Fortran
   )
 set (PROJECT_DESCRIPTION "WSJT-X: Digital Modes for Weak Signal Communications in Amateur Radio")
diff --git a/NEWS b/NEWS
index 7d44f83eb..ab2c4a86a 100644
--- a/NEWS
+++ b/NEWS
@@ -11,6 +11,22 @@
                                                          
 Copyright 2001 - 2023 by Joe Taylor, K1JT, and the WSJT Development Team
 
+                        Release: WSJT-X 2.6.1
+                           January 16, 2023
+                      -------------------------
+
+WSJT-X 2.6.1 is mostly a bug fix release for Q65.  It has the following  
+changes since release 2.6.0:
+
+ - Fix a flaw in Q65 mode that prevented proper display of the T/R 
+   period spinner.
+
+ - Correct the reference to "ARRL International Digital Contest" in the 
+   Release Notes.
+
+ - Make the initialization of the decoded text font more robust.
+
+
                         Release: WSJT-X 2.6.0
                            January 6, 2023
                       -------------------------
@@ -20,7 +36,7 @@ version 2.5.4.  Its major enhancements include the following:
 
  - Mode selection buttons on main window for FT4, FT8, JT65, MSK144, 
    Q65, and FT8's Hound mode
- - Support for the ARRL International DX Contest
+ - Support for the ARRL International Digital Contest
  - Performance enhancements for the FT8 and Q65 modes
  - New features for EME Echo mode, including calibrated SNR reports
  - Several new convenience features for Fox operators 
diff --git a/Release_Notes.txt b/Release_Notes.txt
index 098ab5e27..4556f690b 100644
--- a/Release_Notes.txt
+++ b/Release_Notes.txt
@@ -11,6 +11,22 @@
                                                          
 Copyright 2001 - 2023 by Joe Taylor, K1JT, and the WSJT Development Team
 
+                        Release: WSJT-X 2.6.1
+                           January 16, 2023
+                      -------------------------
+
+WSJT-X 2.6.1 is mostly a bug fix release for Q65.  It has the following  
+changes since release 2.6.0:
+
+ - Fix a flaw in Q65 mode that prevented proper display of the T/R 
+   period spinner.
+
+ - Correct the reference to "ARRL International Digital Contest" in the 
+   Release Notes.
+
+ - Make the initialization of the decoded text font more robust.
+
+
                         Release: WSJT-X 2.6.0
                            January 6, 2023
                       -------------------------

From 02bf562712868e1877c98e4f0f643693668ea4d4 Mon Sep 17 00:00:00 2001
From: Uwe Risse <dg2ycb@gmx.de>
Date: Sat, 7 Jan 2023 10:30:34 +0100
Subject: [PATCH 3/4] Update README.

---
 README | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/README b/README
index 093333290..5797cd20c 100644
--- a/README
+++ b/README
@@ -11,9 +11,9 @@
                                                          
                                                          
                                                          
-Copyright (C) 2001 - 2021 by Joe Taylor, K1JT.
+Copyright (C) 2001 - 2023 by Joe Taylor, K1JT.
 
-WSJT-X Version 2.5 offers eleven different protocols or modes: FT4,
+WSJT-X Version 2.6.1 offers eleven different protocols or modes: FT4,
 FT8, JT4, JT9, JT65, Q65, FST4, MSK144, WSPR, FST4W, and Echo. The
 first seven are designed for making reliable QSOs under weak-signal
 conditions. They use nearly identical message structure and source
@@ -99,7 +99,7 @@ https://wsjtx.groups.io/g/main email reflector.
 
 Project web site:
 
-https://www.physics.princeton.edu/pulsar/K1JT/wsjtx.html
+https://wsjt.sourceforge.io/wsjtx.html
 
 Project mailing list (shared with other applications from the same
 team):

From f0e387bf18f3de67ed4d15f665572e3f24eb0e15 Mon Sep 17 00:00:00 2001
From: Steven Franke <s.j.franke@icloud.com>
Date: Sat, 7 Jan 2023 07:44:10 -0600
Subject: [PATCH 4/4] Replace sprintf with snprintf so that clang doesn't
 complain.

---
 widgets/mainwindow.cpp | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/widgets/mainwindow.cpp b/widgets/mainwindow.cpp
index 2f9d68a44..b9c612e14 100644
--- a/widgets/mainwindow.cpp
+++ b/widgets/mainwindow.cpp
@@ -4819,9 +4819,9 @@ void MainWindow::guiUpdate()
     if(m_transmitting) {
       char s[42];
       if(SpecOp::FOX==m_specOp and ui->tabWidget->currentIndex()==1) {
-        sprintf(s,"Tx:  %d Slots",foxcom_.nslots);
+        snprintf(s,sizeof(s),"Tx:  %d Slots",foxcom_.nslots);
       } else {
-        sprintf(s,"Tx: %s",msgsent);
+        snprintf(s,sizeof(s),"Tx: %s",msgsent);
       }
       m_nsendingsh=0;
       if(s[4]==64) m_nsendingsh=1;
diff --git a/widgets/mainwindow.cpp b/widgets/mainwindow.cpp
index 977946d03..2f9d68a44 100644
--- a/widgets/mainwindow.cpp
+++ b/widgets/mainwindow.cpp
@@ -663,9 +663,9 @@ MainWindow::MainWindow(QDir const& temp_directory, bool multiple,
   connect (ui->decodedTextBrowser2, &DisplayText::erased, this, &MainWindow::rx_frequency_activity_cleared);
 
   // initialize decoded text font and hook up font change signals
-  // defer initialization until after construction otherwise menu
-  // fonts do not get set
-  QTimer::singleShot (0, this, SLOT (initialize_fonts ()));
+  // defer initialization until after construction otherwise menu fonts do not get set
+  // with 50 ms delay we are on the save side
+  QTimer::singleShot (50, this, SLOT (initialize_fonts ()));
   connect (&m_config, &Configuration::text_font_changed, [this] (QFont const& font) {
       set_application_font (font);
     });
